boofun.utils.exceptions
=======================

.. automodule:: boofun.utils.exceptions


   .. rubric:: Classes

   .. autosummary::

      ErrorCode

   .. rubric:: Exceptions

   .. autosummary::

      BooleanFunctionError
      ConfigurationError
      ConversionError
      EvaluationError
      InvalidInputError
      InvalidRepresentationError
      InvalidTruthTableError
      InvariantViolationError
      ResourceUnavailableError
      ValidationError
